gedidb.L4AGranule
=================

.. currentmodule:: gedidb

.. autoclass:: L4AGranule

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~L4AGranule.__init__
      ~L4AGranule.beam
      ~L4AGranule.build_virtual_dataset
      ~L4AGranule.clear
      ~L4AGranule.close
      ~L4AGranule.copy
      ~L4AGranule.create_dataset
      ~L4AGranule.create_dataset_like
      ~L4AGranule.create_group
      ~L4AGranule.create_virtual_dataset
      ~L4AGranule.flush
      ~L4AGranule.get
      ~L4AGranule.items
      ~L4AGranule.iter_beams
      ~L4AGranule.keys
      ~L4AGranule.list_beams
      ~L4AGranule.move
      ~L4AGranule.pop
      ~L4AGranule.popitem
      ~L4AGranule.require_dataset
      ~L4AGranule.require_group
      ~L4AGranule.setdefault
      ~L4AGranule.update
      ~L4AGranule.validate_beam_name
      ~L4AGranule.values
      ~L4AGranule.visit
      ~L4AGranule.visit_links
      ~L4AGranule.visititems
      ~L4AGranule.visititems_links
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~L4AGranule.abstract
      ~L4AGranule.attrs
      ~L4AGranule.driver
      ~L4AGranule.file
      ~L4AGranule.filename
      ~L4AGranule.filename_metadata
      ~L4AGranule.id
      ~L4AGranule.libver
      ~L4AGranule.meta_block_size
      ~L4AGranule.mode
      ~L4AGranule.n_beams
      ~L4AGranule.name
      ~L4AGranule.parent
      ~L4AGranule.product
      ~L4AGranule.ref
      ~L4AGranule.regionref
      ~L4AGranule.start_datetime
      ~L4AGranule.swmr_mode
      ~L4AGranule.userblock_size
      ~L4AGranule.uuid
      ~L4AGranule.version_granule
      ~L4AGranule.version_product
   
   